From a381c7441140e77208c0ed3a8dd45cb61197afd9 Mon Sep 17 00:00:00 2001
From: Andreas Sturmlechner <asturm@gentoo.org>
Date: Thu, 24 Sep 2020 22:34:28 +0200
Subject: [PATCH] xembed-sni-proxy: Allow standalone build

---
 xembed-sni-proxy/CMakeLists.txt | 36 +++++++++++++++++++++++++++++++++
 1 file changed, 36 insertions(+)

diff --git a/xembed-sni-proxy/CMakeLists.txt b/xembed-sni-proxy/CMakeLists.txt
index bcc583bfa..41d50d112 100644
--- a/xembed-sni-proxy/CMakeLists.txt
+++ b/xembed-sni-proxy/CMakeLists.txt
@@ -1,3 +1,35 @@
+project(xembed-sni-proxy)
+
+if(${CMAKE_SOURCE_DIR} STREQUAL ${xembed-sni-proxy_SOURCE_DIR})
+    set(PROJECT_VERSION "GENTOO_PV")
+    set(PROJECT_VERSION_MAJOR 5)
+
+    cmake_minimum_required(VERSION 3.16)
+
+    set(QT_MIN_VERSION "5.15.0")
+    set(KF5_MIN_VERSION "5.89")
+    find_package(Qt5 ${QT_MIN_VERSION} CONFIG REQUIRED COMPONENTS Core DBus X11Extras)
+    find_package(ECM ${KF5_MIN_VERSION} REQUIRED NO_MODULE)
+    set(CMAKE_MODULE_PATH ${ECM_MODULE_PATH} ${ECM_KDE_MODULE_DIR})
+
+    include(KDEInstallDirs)
+    include(KDECMakeSettings)
+    include(KDECompilerSettings NO_POLICY_SCOPE)
+    include(FeatureSummary)
+    include(ECMQtDeclareLoggingCategory)
+    include(ECMConfiguredInstall)
+
+    find_package(KF5WindowSystem ${KF5_MIN_VERSION} REQUIRED)
+    find_package(X11 REQUIRED)
+    find_package(XCB MODULE REQUIRED COMPONENTS XCB RANDR)
+    set_package_properties(XCB PROPERTIES TYPE REQUIRED)
+
+    configure_file(../config-X11.h.cmake ${CMAKE_CURRENT_BINARY_DIR}/config-X11.h)
+else()
+    set(PROJECT_VERSION "5.24.80")
+    set(PROJECT_VERSION_MAJOR 5)
+endif()
+
 add_definitions(-DQT_NO_CAST_TO_ASCII
 -DQT_NO_CAST_FROM_ASCII
 -DQT_NO_CAST_FROM_BYTEARRAY)
@@ -64,3 +96,7 @@ install(TARGETS xembedsniproxy ${KDE_INSTALL_TARGETS_DEFAULT_ARGS})
 install(FILES xembedsniproxy.desktop DESTINATION ${KDE_INSTALL_AUTOSTARTDIR})
 
 ecm_install_configured_files(INPUT plasma-xembedsniproxy.service.in @ONLY DESTINATION  ${KDE_INSTALL_SYSTEMDUSERUNITDIR})
+
+if ("${CMAKE_BINARY_DIR}" STREQUAL "${CMAKE_CURRENT_BINARY_DIR}")
+    feature_summary(WHAT ALL FATAL_ON_MISSING_REQUIRED_PACKAGES)
+endif()
-- 
2.34.1

